==> haskell-fdo-notify-0.3.1-902-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-5kFHnMhGCqk8CkjbpG6pXz
key:                  fdo-notify-0.3.1-5kFHnMhGCqk8CkjbpG6pXz
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  5bd20760d35db3f49a128ccccf44f41b
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-5kFHnMhGCqk8CkjbpG6pXz
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-GS2uIhkLSQLD2AHFfrlZSJ

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-903-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-GpIyjQmmXUu6IdOqfvWwV
key:                  fdo-notify-0.3.1-GpIyjQmmXUu6IdOqfvWwV
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  729050ba391fe8d4d2285a3a6a6cfab6
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-GpIyjQmmXUu6IdOqfvWwV
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-5FImutXgDOBEllfdlYh9dC

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
